---
title: <span class="badge object-type-scalar"></span> Curie
---
# <span class="badge object-type-scalar"></span> Curie

Radiation: curie (Ci)

## Definition

```python
# Radiation: curie (Ci)
Curie: typing.Literal["radci"] = "radci"
```
